@@ -2,7 +2,7 @@ from typing import Sized, Tuple, Union
 
 import torch
 from torch import Tensor
-from quaterion_models import MetricModel
+from quaterion_models import SimilarityModel
 
 from quaterion.eval.base_metric import BaseMetric
 
@@ -23,12 +23,14 @@ class BaseSampler:
         self,
         sample_size=-1,
         device: Union[torch.device, str, None] = None,
+        log_progress: bool = True,
     ):
+        self.log_progress = log_progress
         self.sample_size = sample_size
         self.device = device
 
     def sample(
-        self, dataset: Sized, metric: BaseMetric, model: MetricModel
+        self, dataset: Sized, metric: BaseMetric, model: SimilarityModel
     ) -> Tuple[Tensor, Tensor]:
         """Sample objects and labels to calculate metrics
 
