@@ -1,4 +1,5 @@
 import os
+import warnings
 
 from typing import (
     Union,
@@ -8,11 +9,12 @@ from typing import (
 
 import pytorch_lightning as pl
 import torch.cuda
+from pytorch_lightning.utilities.warnings import PossibleUserWarning
 from loguru import logger
 from quaterion_models.encoders import Encoder
 from torch.utils.data import DataLoader
 
-from quaterion.train.cache.cache_train_collater import CacheTrainCollator
+from quaterion.train.cache.cache_train_collator import CacheTrainCollator
 from quaterion.dataset.similarity_data_loader import SimilarityDataLoader
 from quaterion.train.cache import (
     CacheConfig,
@@ -180,7 +182,7 @@ class CacheMixin:
         else:
             key_extractors = cache_config.key_extractors
 
-        cache_collater = CacheTrainCollator(
+        cache_collator = CacheTrainCollator(
             pre_collate_fn=train_dataloader.pre_collate_fn,
             encoder_collates={
                 name: encoder.get_collate_fn() for name, encoder in encoders.items()
@@ -190,9 +192,9 @@ class CacheMixin:
             mode=CacheMode.TRAIN,
         )
 
-        train_dataloader.collate_fn = cache_collater
+        train_dataloader.collate_fn = cache_collator
         if val_dataloader is not None:
-            val_dataloader.collate_fn = cache_collater
+            val_dataloader.collate_fn = cache_collator
 
         # Setup different cache key salt for train and val
         train_dataloader.set_salt("train")
@@ -207,19 +209,26 @@ class CacheMixin:
             if is_full_cache_possible:
                 cls._label_cache_train_mode(train_dataloader, val_dataloader)
 
-            cache_collater.mode = CacheMode.FILL
-            cls._fill_cache(
-                trainer=trainer,
-                cache_encoders=cache_encoders,
-                train_dataloader=train_dataloader,
-                val_dataloader=val_dataloader,
-                cache_config=cache_config,
-            )
-            cache_collater.mode = CacheMode.TRAIN
-            logger.debug("Caching has been successfully finished")
-            cls.save_cache(
-                cache_config.save_dir, cache_encoders, train_dataloader, val_dataloader
-            )
+            cache_collator.mode = CacheMode.FILL
+            with warnings.catch_warnings():
+                warnings.filterwarnings(
+                    "ignore", category=PossibleUserWarning, message="The dataloader, .*"
+                )
+                cls._fill_cache(
+                    trainer=trainer,
+                    cache_encoders=cache_encoders,
+                    train_dataloader=train_dataloader,
+                    val_dataloader=val_dataloader,
+                    cache_config=cache_config,
+                )
+                cache_collator.mode = CacheMode.TRAIN
+                logger.debug("Caching has been successfully finished")
+                cls.save_cache(
+                    cache_config.save_dir,
+                    cache_encoders,
+                    train_dataloader,
+                    val_dataloader,
+                )
 
         else:
             cls.load_cache(
@@ -265,7 +274,7 @@ class CacheMixin:
                 cache_encoders,
             ),
             [cache_train_dataloader, cache_val_dataloader],
-            return_predictions=False,
+            return_predictions=True,
         )
 
     @classmethod
